#!/usr/bin/python
# -*- coding: utf-8 -*-
import json, httplib, urllib, sys, os, re, argparse
from versionManager import *
from profileManager import *
from deviceManager import *
from appManager import *
from config import *

def dailyBuild():
	sBathPath = "."

	###prepare params
	#版本号，用于水印，以及info.plist中
	sDayVer = VersionManager().getCurVer()
	#每个APP的AppDelegate.m中设置的 [[RTRequestProxy sharedInstance] setAppName:xxxx];
	sAppName = AppManager().getAppName()
	#Provioning Profile文件名，字典类型，d => "dictionary"
	dProfile = ProfileManager().getProfileByAppName(sAppName)

	#可不设置，默认会build当前目录下的xcodeproj文件以及第一个target
	#sProjName = "AiFang.xcodeproj"
	sTargetIpaName = sAppName + "_" + sDayVer

	#-configuration 默认Debug 或 Release
	sConf = "Release"

	###xcodebuild shell puzzle
	sShell = "xcodebuild"
	#if len(sProjName) > 0:
	#	sShell += ' -project {}'.format(sProjName)
	#if len(sTarget) > 0:
	#	sShell += ' -target {}'.format(sTarget)
	if len(sConf) > 0:
		sShell += ' -configuration {}'.format(sConf)
	if 'name' in dProfile:
		sShell += ' {}={}'.format(dProfile["name"],dProfile["hash"])
	sShell += ' OBJROOT={0}/build SYMROOT={0}/build'.format(sBathPath)
	sShell += ' clean build'
	os.chdir(sBathPath)
	#print sShell
	# sys.exit()
	result = os.system(sShell)
	if 0 != result:
		print "Build failed"
	else:
		print "\n\n\n\033[0;31m打包成功\n\n\n"

	###xcrun PackageApplication puzzle
	sShellXcrun = 'xcrun -sdk iphoneos PackageApplication -v'
	sAppPath = AppManager().getBuildAppPath()
	sOutPutFile = '~/Desktop/{}.ipa'.format(sTargetIpaName)
	if len(sAppPath) > 0:
		sShellXcrun += ' {}'.format(sAppPath)
	if len(sTargetIpaName) > 0:
		sShellXcrun += '  -o {}'.format(sOutPutFile)
	result = os.system(sShellXcrun)
	if 0 != result:
		print "Pack failed"

	###scp to ios.dev.anjuke.com
	sDirName = AppManager().getPublishPathByAppName(sAppName)
	sShellScp = 'scp {} mobile@192.168.201.214:{}'.format(sOutPutFile,sDirName)
	result = os.system(sShellScp)

	if 0 != result:
		print "Scp failed"


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
from config import *

class DeviceManager:
	_instance = None

	def __new__(cls, *args, **kwargs):
		if not cls._instance:  
			cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)  
		return cls._instance

	def getDeviceTypeByAppName(self, appName):
		return "iphoneos"


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os, re, sys
from config import *

class AppManager:
	_instance = None
	def __new__(cls, *args, **kwargs):
		if not cls._instance:  
			cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)  
		return cls._instance

	def __init__(self):
		pass

	def getPublishPathByAppName(self, appName):
		if appName in map_appname_path:
			return map_appname_path[appName]
		else:
			print "{} not in map_appname_path".format(appName)
			sys.exit(1)

	def getAppName(self):
		return self.getAppNameByRespName(
				self.getRespNameByAppPath(
						self.getCurrentPath()
					)
			)

	def getAppNameByRespName(self,respName):
		if respName in map_resp_appname:
			return map_resp_appname[respName]
		else:
			print "{} not in map_resp_appname".format(respName)
			sys.exit(1)

	def getRespNameByAppPath(self,path):
		sOriginPath = self.getCurrentPath()
		os.chdir(path)
		#若匹配“remote.*url”有多行，则获取最后一行的最后一个‘/’后面的字符串
		resp_path = os.popen("git config -l|grep -p 'remote.*url='|awk -F'=' '{print $2}'").read()
		respName = re.sub(r'[\r\n]','',re.split('/', resp_path)[-1])
		os.chdir(sOriginPath)
		return respName

	def getCurrentPath(self):
		return os.getcwd()

	def getBuildAppPath(self):
		sPath = 'build/Release-iphoneos/'
		sCommand = "find {} -name \"*.app\"".format(sPath)
		sBuildAppPath = easySys(sCommand)
		return sBuildAppPath


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os, datetime, re
from config import *

class VersionManager:
	_instance = None

	def __new__(cls, *args, **kwargs):
		if not cls._instance:  
			cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)  
		return cls._instance

	def getCurVer(self):
		return "{}_{}_{}".format(self.getType(),self.getDate(),self.getTodayVersion())

	def getType(self):
		# rc daily real store
		return "daily"

	def getDate(self):
		today = datetime.date.today()
		return today.strftime('%Y%m%d')

	def getTodayVersion(self):
		return re.sub(r'[\r\n]','',os.popen("git rev-parse --short HEAD").read())


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
from config import *

class ProfileManager:
	_instance = None

	def __new__(cls, *args, **kwargs):
		if not cls._instance:  
			cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)  
		return cls._instance

	def getProfileByAppName(self, appName):
		#TODO 未来可能不同的app对应不同的Profile
	 	result = {
		 			"name":'\"PROVISIONING_PROFILE[sdk={}]\"'.format(self.getSDKType()),
		 			"hash":'\"77DECEE6-E3E4-4429-B986-DD6AC8948F9C\"'
	 			}
		return result

	def getProfileByAppNameAndBuildType(self, appName, buildType):
		#TODO 不同的build类型，daily RC 渠道包 APP_STORE
	 	result = {
		 			"name":'\"PROVISIONING_PROFILE[sdk={}]\"'.format(self.getSDKType()),
		 			"hash":'\"77DECEE6-E3E4-4429-B986-DD6AC8948F9C\"'
	 			}
		return result

	def getSDKType(self):
		return "iphoneos*"


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os,re

APPNAME_XINFANG = 'i-xinfang'
APPNAME_XINFANG_PAD = 'p-xinfang'
APPNAME_ANJUKE = 'i-anjuke'
APPNAME_ANJUKE_PAD = 'p-anjuke'
APPNAME_HAOZU = 'i-haozu2.0'
APPNAME_HAOZU_PAD = 'p-haozu'
APPNAME_JINPU = 'i-jinpu'
APPNAME_BROKER = 'i-broker'

map_resp_appname = {
	'aifang':APPNAME_XINFANG,
	'xinfangPad':APPNAME_XINFANG_PAD,
	'Anjuke2':APPNAME_ANJUKE,
	'anjukePad':APPNAME_ANJUKE_PAD,
	'Haozu':APPNAME_HAOZU,
	'HaozuPad':APPNAME_HAOZU_PAD,
	'JinPu':APPNAME_JINPU,
	'AnjukeBroker':APPNAME_BROKER
}

basePath = '/var/www/apps/{}/ipa/'
map_appname_path = {
	APPNAME_XINFANG : basePath.format('newhouse'),
	APPNAME_XINFANG_PAD : basePath.format('xinfangPad'),
	APPNAME_ANJUKE : basePath.format('anjuke'),
	APPNAME_ANJUKE_PAD : basePath.format('anjukePad'),
	APPNAME_HAOZU : basePath.format('haozu'),
	APPNAME_HAOZU_PAD : basePath.format('haozuPad'),
	APPNAME_JINPU : basePath.format('JinPu'),
	APPNAME_BROKER : basePath.format('AnjukeBrokerEnterprise')
}